@@ -45,7 +45,7 @@ def check_env(
     if env_name not in existing_env_names:
         log_func(f"Environment {env_name} doesn't exist; creating")
         # Environment doesn't exist, so create it
-        subprocess.check_call([conda, "env", "create", "-f", env_fpath])
+        subprocess.check_call([conda, "env", "create", "-y", "-f", env_fpath])
         env_needs_rebuild = False
         env_needs_export = True
     else:
@@ -84,10 +84,18 @@ def check_env(
                 ryaml.dump(env_check, f)
         # Determine if the env matches
         env_needs_rebuild = False
-        existing_conda_deps = env_check["dependencies"][:-1]
-        existing_pip_deps = env_check["dependencies"][-1]["pip"]
-        required_conda_deps = env_spec["dependencies"][:-1]
-        required_pip_deps = env_spec["dependencies"][-1]["pip"]
+        if isinstance(env_check["dependencies"][-1], dict):
+            existing_conda_deps = env_check["dependencies"][:-1]
+            existing_pip_deps = env_check["dependencies"][-1]["pip"]
+        else:
+            existing_conda_deps = env_check["dependencies"]
+            existing_pip_deps = []
+        if isinstance(env_spec["dependencies"][-1], dict):
+            required_conda_deps = env_spec["dependencies"][:-1]
+            required_pip_deps = env_spec["dependencies"][-1]["pip"]
+        else:
+            required_conda_deps = env_spec["dependencies"]
+            required_pip_deps = []
         log_func("Checking conda dependencies")
         for dep in required_conda_deps:
             dep_split = dep.split("=")
@@ -101,6 +109,8 @@ def check_env(
                 env_needs_rebuild = True
                 break
             elif version is None:
+                # TODO: This does not handle specification of only major or
+                # major+minor version
                 if package not in [
                     d.split("=")[0] for d in existing_conda_deps
                 ]:
